package cn.fw.dalaran.domain.vo;

import cn.fw.dalaran.domain.db.config.ConfigBean;
import cn.fw.dalaran.domain.db.config.ValidConfig;
import lombok.Data;

import javax.validation.constraints.NotNull;

/**
 * @author wmy3969
 * @version 1.0
 * @date 2022/1/8 16:56
 * @Description 有效视频/直播判断配置视图
 */
@Data
public class ValidConfigVo {
    /**
     * id
     */
    private Long id;
    /**
     * 集团id
     */
    @NotNull(message = "集团id不能为空")
    private Long groupId;
    /**
     * 活动主题话题过滤是否有效
     */
    private Integer themeTagEffect;

    /*视频独有参数*/
    /**
     * 点赞数
     */
    private ConfigBean likeCntVideo;
    /**
     * 评论数
     */
    private ConfigBean commentCntVideo;
    /**
     * 分享数
     */
    private ConfigBean shareCntVideo;
    /**
     * 增粉数
     */
    private ConfigBean newFansCntVideo;
    /**
     * 播放数
     */
    private ConfigBean playCnt;
    /**
     * 完整播放量
     */
    private ConfigBean fullPlayCnt;

    /*直播独有参数*/
    /**
     * 点赞数
     */
    private ConfigBean likeCntLive;
    /**
     * 评论数
     */
    private ConfigBean commentCntLive;
    /**
     * 分享数
     */
    private ConfigBean shareCntLive;
    /**
     * 增粉数
     */
    private ConfigBean newFansCntLive;
    /**
     * 观看人数
     */
    private ConfigBean watchUser;
    /**
     * 在线峰值人数
     */
    private ConfigBean watchUserPeak;
    /**
     * 直播时长
     */
    private ConfigBean duration;

    /**
     * vo->db
     *
     * @return 将视图传参转换成DB
     */
    public static ValidConfig toDB(ValidConfigVo vo) {
        return ValidConfig.builder()
                .id(vo.getId())
                .groupId(vo.getGroupId())
                .themeTagEffect(vo.getThemeTagEffect())
                // 视频独有参数
                .likeCntVideo(vo.getLikeCntVideo().getIndexMin())
                .likeCntEffectVideo(vo.getLikeCntVideo().getEffect())
                .commentCntVideo(vo.getCommentCntVideo().getIndexMin())
                .commentCntEffectVideo(vo.getCommentCntVideo().getEffect())
                .shareCntVideo(vo.getShareCntVideo().getIndexMin())
                .shareCntEffectVideo(vo.getShareCntVideo().getEffect())
                .newFansCntVideo(vo.getNewFansCntVideo().getIndexMin())
                .newFansCntEffectVideo(vo.getNewFansCntVideo().getEffect())
                .playCnt(vo.getPlayCnt().getIndexMin())
                .playCntEffect(vo.getPlayCnt().getEffect())
                .fullPlayCnt(vo.getFullPlayCnt().getIndexMin())
                .fullPlayCntEffect(vo.getFullPlayCnt().getEffect())
                // 直播独有参数
                .likeCntLive(vo.getLikeCntLive().getIndexMin())
                .likeCntEffectLive(vo.getLikeCntLive().getEffect())
                .commentCntLive(vo.getCommentCntLive().getIndexMin())
                .commentCntEffectLive(vo.getCommentCntLive().getEffect())
                .shareCntLive(vo.getShareCntLive().getIndexMin())
                .shareCntEffectLive(vo.getShareCntLive().getEffect())
                .newFansCntLive(vo.getNewFansCntLive().getIndexMin())
                .newFansCntEffectLive(vo.getNewFansCntLive().getEffect())
                .watchUser(vo.getWatchUser().getIndexMin())
                .watchUserEffect(vo.getWatchUser().getEffect())
                .watchUserPeak(vo.getWatchUserPeak().getIndexMin())
                .watchUserPeakEffect(vo.getWatchUserPeak().getEffect())
                .duration(vo.getDuration().getIndexMin())
                .durationEffect(vo.getDuration().getEffect())
                .build();
    }
}
