package cn.fw.dalaran.rpc.backlog;

import cn.fw.backlog.sdk.api.BacklogItemApi;
import cn.fw.backlog.sdk.api.param.BacklogItemCancelReq;
import cn.fw.backlog.sdk.api.param.BacklogItemCommitReq;
import cn.fw.backlog.sdk.api.param.BacklogItemPlanReq;
import cn.fw.dalaran.rpc.backlog.dto.BackLogItemDTO;
import cn.fw.data.base.domain.common.Message;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author kurisu
 * @date 2020-08-18 15:53
 * @description 待办rpc
 */
@Slf4j
@Service
public class TodoRpcService {

    private final BacklogItemApi backlogItemApi;

    @Autowired
    public TodoRpcService(final BacklogItemApi backlogItemApi) {
        this.backlogItemApi = backlogItemApi;
    }

    /**
     * 生成待办
     *
     * @param dto
     */
    public boolean push(BackLogItemDTO dto) {
        final String func = "调用ERP系统生成待办";
        try {
            log.info("{}：params: [{}]", func, dto);
            BacklogItemPlanReq req = new BacklogItemPlanReq();
            BeanUtils.copyProperties(dto, req);
            req.setPlanTime(dto.getDataTime());
            Message<Void> message = backlogItemApi.planBacklogItem(req);
            log.info("{} 结果：{} desc: {}", func, message.isSuccess(), message.getResult());
            return message.isSuccess();
        } catch (Exception e) {
            log.error("{}失败，params：{}", func, dto, e);
            return false;
        }
    }

    /**
     * 完成待办
     *
     * @param dto
     */
    public boolean complete(BackLogItemDTO dto) {
        final String func = "调用ERP系统完成待办";
        try {
            log.info("{}：params: [{}]", func, dto);
            BacklogItemCommitReq req = new BacklogItemCommitReq();
            BeanUtils.copyProperties(dto, req);
            req.setCommitTime(dto.getDataTime());
            Message<Void> message = backlogItemApi.commitBacklogItem(req);
            log.info("{} 结果：{} desc: {}", func, message.isSuccess(), message.getResult());
            return message.isSuccess();
        } catch (Exception e) {
            log.error("{}失败，params：{}", func, dto, e);
            return false;
        }
    }

    /**
     * 取消待办
     *
     * @param dto
     */
    public boolean cancel(BackLogItemDTO dto) {
        final String func = "调用ERP系统取消待办";
        try {
            log.info("{}：params: [{}]", func, dto);
            BacklogItemCancelReq req = new BacklogItemCancelReq();
            BeanUtils.copyProperties(dto, req);
            Message<Void> message = backlogItemApi.cancelBacklogItem(req);
            log.info("{} 结果：{} desc: {}", func, message.isSuccess(), message.getResult());
            return message.isSuccess();
        } catch (Exception e) {
            log.error("{}失败，params：{}", func, dto, e);
            return false;
        }
    }
}
