package cn.fw.dalaran.sdk.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author kurisu
 * @date 2020-08-11 17:37
 * @description 业务类型   1：短视频 2：直播
 */
public enum DemoEnum implements IEnum<Integer> {
    /**
     * 短视频
     */
    VIDEO(1, "短视频"),
    /**
     * 直播
     */
    LIVE(2, "直播"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    DemoEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static DemoEnum ofValue(final Integer value) {
        for (final DemoEnum typeEnum : DemoEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final DemoEnum typeEnum : DemoEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
