package cn.fw.dalaran.server.task;

import cn.fw.dalaran.service.DingTalkService;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;
import java.nio.charset.StandardCharsets;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Objects;

/**
 * @author wmy3969
 * @version 1.0
 * @date 2022/2/8 10:54
 * @Description 获取数据抓取服务器状态定时任务
 */
@Slf4j
@Component
public class GetStatusTask {

    @Value("${spring.profiles.active}")
    private String env;// 获取系统当前环境
    private static Integer failTimes = 0;// 服务器异常次数
    private static final Integer ALARM_THRESHOLD_VALUE = 3;// 服务器异常次数报警阈值
    private static final String SERVER_URL = "http://irai.feewee.cn/status/getSimpleStatus";// 抓数据服务器接口地址(线上)

    /**
     * 10分钟获取一次抓数据服务器状态
     */
    @Scheduled(cron = "0 0/10 * * * *")
    public void getStatus() throws Exception {
        if (!env.contains("prd")) {
            return;
        }
        final JSONObject response = JSONObject.parseObject(this.GET(SERVER_URL));
        final Date now = new Date();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        final String format = sdf.format(now);
        if (Objects.nonNull(response) && response.getBoolean("data")) {
            if (failTimes >= ALARM_THRESHOLD_VALUE) {
                DingTalkService.sendToEverybody(format + " 自媒体服务器故障已恢复");
            }
            failTimes = 0;
        } else {
            ++failTimes;
            log.error(format + " 已经连续" + failTimes + "次获取自媒体服务器状态失败, 请及时检查服务器运行状态");
        }
        if (Objects.equals(failTimes, ALARM_THRESHOLD_VALUE)) {
            DingTalkService.sendToEverybody(format + " 已经连续" + failTimes + "次获取自媒体服务器状态失败, 请及时检查服务器运行状态");
        }
    }

    /**
     * 每天凌晨重置失败次数
     */
    @Scheduled(cron = "0 0 0 * * *")
    public void initFailTimes() {
        failTimes = 0;
    }

    /**
     * 测试
     */
    //@Scheduled(fixedRate = 15000L)
    public void test() {
        //log.info("系统临时文件夹路径为: " + System.getProperty("java.io.tmpdir"));
    }

    /**
     * 发送GET请求
     *
     * @param url 请求地址
     * @return
     */
    private String GET(String url) {
        StringBuilder result = new StringBuilder();
        BufferedReader in = null;
        try {
            URL realUrl = new URL(url);
            URLConnection connection = realUrl.openConnection();// 打开和URL之间的连接
            // 设置通用的请求属性
            connection.setRequestProperty("accept", "*/*");
            connection.setRequestProperty("connection", "Keep-Alive");
            connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            connection.connect();// 建立实际的连接
            /*Map<String, List<String>> map = connection.getHeaderFields();// 获取所有响应头字段
            for (String key : map.keySet()) {// 遍历所有的响应头字段
                System.out.println(key + "--->" + map.get(key));
            }*/
            in = new BufferedReader(new InputStreamReader(connection.getInputStream(), StandardCharsets.UTF_8));// 定义 BufferedReader输入流来读取URL的响应, 防止乱码
            String line;
            while ((line = in.readLine()) != null) {
                result.append(line);
            }
        } catch (Exception e) {
            log.error("发送GET请求出现异常！", e);
        } finally {// 使用finally块来关闭输入流
            try {
                if (in != null) {
                    in.close();
                }
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        return result.toString();
    }
}
