package cn.fw.dalaran.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.File;
import java.util.Objects;

/**
 * @author wmy3969
 * @version 1.0
 * @date 2022/6/11 16:12
 * @Description 公共服务
 */
@Slf4j
@Component
public class Common {
    @Value("${spring.profiles.active}")
    private String env;// 获取系统当前环境

    /**
     * 获取主题封面图路径
     */
    public String getActivityThemeCoverDir() {
        String osName = System.getProperties().getProperty("os.name");
        if (osName.contains("Windows"))
            return System.getProperty("java.io.tmpdir");// 获取当前环境临时文件夹路径
        if (env.contains("prd"))
            return "/web/logs/server.dalaran.feewee.cn/";
        else
            return "/web/logs/testserver.dalaran.feewee.cn/";
    }

    /**
     * 删除文件
     *
     * @param filePath 文件路径
     * @return 操作结果
     */
    public boolean deleteFile(String filePath) {
        File file = new File(filePath);
        if (file.exists() && file.isFile()) {// 如果文件路径只有单个文件
            boolean result = file.delete();
            if (result)
                log.info(String.format("删除文件[%s]成功", filePath));
            else
                log.info(String.format("删除文件[%s]失败", filePath));
            return result;
        } else {
            log.error(String.format("文件[%s]不存在", filePath));
            return false;
        }
    }

    /**
     * 删除文件夹
     *
     * @param dirPath       文件夹路径
     * @param appointedFile 指定开始递归的文件(可不传)
     * @return 操作结果
     */
    public boolean deleteAllFile(String dirPath, File... appointedFile) {
        File dirFile = Objects.equals(0, appointedFile.length) ? new File(dirPath) : appointedFile[0];
        if (!dirFile.isDirectory()) {// 如果dir对应的文件不存在, 或者不是一个目录, 则退出
            log.error(String.format("删除文件夹失败：[%s]不是文件夹或不存在", dirPath));
            return false;
        }
        // 递归删除文件夹中的所有文件包括子文件夹
        boolean flag = true;
        File[] files = dirFile.listFiles();
        Objects.requireNonNull(files);
        for (File file : files) {
            if (file.isFile())
                flag = this.deleteFile(file.getAbsolutePath());// 删除子文件
            else if (file.isDirectory())
                flag = this.deleteAllFile(file.getAbsolutePath());// 递归
            if (!flag) {
                log.error("删除文件夹失败");
                return false;
            }
        }
        boolean result = dirFile.delete();// 删除当前文件夹
        if (result)
            log.info(String.format("删除文件夹[%s]成功", dirPath));
        return result;
    }

}
