package cn.fw.dalaran.service.data;

import cn.fw.dalaran.domain.db.VideoPool;
import cn.fw.dalaran.domain.dto.PoolQueryDTO;
import cn.fw.dalaran.domain.vo.VideoPoolVO;
import com.baomidou.mybatisplus.extension.service.IService;

import java.time.LocalDate;
import java.util.List;

/**
 * @author kurisu
 * @date 2021-11-17 14:54
 * @description 短视频池service
 */
public interface VideoPoolService extends IService<VideoPool> {

    /**
     * 根据账号删除对应时间的数据
     *
     * @param accountId
     * @param date
     */
    void removeAccountDataByDate(Long accountId, LocalDate date);

    /**
     * 查询短视频池列表
     *
     * @param queryDTO
     * @return
     */
    List<VideoPoolVO> videoList(PoolQueryDTO queryDTO);

    /**
     * 查询短视频数
     *
     * @param queryDTO
     * @return
     */
    long videoCount(PoolQueryDTO queryDTO);

    /**
     * 获取主题活动员工有效视频数
     *
     * @param userId  用户id
     * @param themeId 活动主题id
     * @return 有效视频数
     */
    Integer getValidVideoCnt(Long userId, Long themeId);

    /**
     * 找到最新的video信息
     *
     * @param videoId 视频id
     * @return 该视频id对应的最新的视频
     */
    VideoPool getLatestVideo(String videoId);

}
